﻿/*
  In App.xaml:
  <Application.Resources>
      <vm:ControlTestModelLocator xmlns:vm="clr-namespace:WinAutomator.Plugin.BuildIns"
                                   x:Key="Locator" />
  </Application.Resources>
  
  In the View:
  DataContext="{Binding Source={StaticResource Locator}, Path=ViewModelName}"
*/

using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Ioc;
using Microsoft.Practices.ServiceLocation;

namespace WinAutomator.Plugin.BuildIns
{
    /// <summary>
    /// This class contains static references to all the view models in the
    /// application and provides an entry point for the bindings.
    /// <para>
    /// See http://www.galasoft.ch/mvvm
    /// </para>
    /// </summary>
    public class ControlTestModelLocator
    {
        static ControlTestModelLocator()
        {
            ServiceLocator.SetLocatorProvider(() => SimpleIoc.Default);

            if (ViewModelBase.IsInDesignModeStatic)
            {
                // SimpleIoc.Default.Register<IDataService, Design.DesignDataService>();
            }
            else
            {
                // SimpleIoc.Default.Register<IDataService, DataService>();
            }

            SimpleIoc.Default.Register<ControlTestViewModel>();
            SimpleIoc.Default.Register<WAMessageBoxViewModel>();
        }

        /// <summary>
        /// Gets the Main property.
        /// </summary>
        /// ControlTestViewModel
        /// 
        ControlTestViewModel _instancControlTest;
        public ControlTestViewModel ControlTest
        {
            get
            {
                if (_instancControlTest == null)
                    _instancControlTest = new ControlTestViewModel();

                return _instancControlTest;
            }
        }



        WAMessageBoxViewModel _instancWAMessageBoxViewModel;

        /// <summary>
        /// Gets the ViewModelPropertyName property.
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Performance",
            "CA1822:MarkMembersAsStatic",
            Justification = "This non-static member is needed for data binding purposes.")]
        public WAMessageBoxViewModel WAMessageBoxViewModel
        {
            get
            {
                if (_instancWAMessageBoxViewModel == null)
                    _instancWAMessageBoxViewModel = new WAMessageBoxViewModel();

                return _instancWAMessageBoxViewModel;
            }
        }







    }
}