﻿/*
  In App.xaml:
  <Application.Resources>
      <vm:FileModelLocator xmlns:vm="clr-namespace:WinAutomator.Plugin.Files"
                                   x:Key="Locator" />
  </Application.Resources>
  
  In the View:
  DataContext="{Binding Source={StaticResource Locator}, Path=ViewModelName}"
*/

using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Ioc;
using Microsoft.Practices.ServiceLocation;
using WinAutomator.Plugin.Files.ReadDirectory;

namespace WinAutomator.Plugin.Files
{
    /// <summary>
    /// This class contains static references to all the view models in the
    /// application and provides an entry point for the bindings.
    /// <para>
    /// See http://www.galasoft.ch/mvvm
    /// </para>
    /// </summary>
    public class FileModelLocator
    {
        static FileModelLocator()
        {
            ServiceLocator.SetLocatorProvider(() => SimpleIoc.Default);

            if (ViewModelBase.IsInDesignModeStatic)
            {
                // SimpleIoc.Default.Register<IDataService, Design.DesignDataService>();
            }
            else
            {
                // SimpleIoc.Default.Register<IDataService, DataService>();
            }

            SimpleIoc.Default.Register<ReadDirectoryViewModel>();
        }


        ReadDirectoryViewModel _instancReadDirectoryViewModel;
        /// <summary>
        /// Gets the Main property.
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Performance",
            "CA1822:MarkMembersAsStatic",
            Justification = "This non-static member is needed for data binding purposes.")]
        public ReadDirectoryViewModel ReadDirectory
        {
            get
            {
                if (_instancReadDirectoryViewModel == null)
                    _instancReadDirectoryViewModel = new ReadDirectoryViewModel();

                return _instancReadDirectoryViewModel;
            }
        }
    }
}